// (C) Copyright 2015 Moodle Pty Ltd.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { canLeaveGuard } from '@guards/can-leave';

import { CoreSharedModule } from '@/core/shared.module';
import { AddonModWorkshopIndexPage } from './pages/index/index';
import { AddonModWorkshopComponentsModule } from './components/components.module';
import { AddonModWorkshopSubmissionPage } from './pages/submission/submission';
import { CoreEditorComponentsModule } from '@features/editor/components/components.module';
import { AddonModWorkshopAssessmentPage } from './pages/assessment/assessment';
import { AddonModWorkshopEditSubmissionPage } from './pages/edit-submission/edit-submission';

const routes: Routes = [
    {
        path: ':courseId/:cmId',
        component: AddonModWorkshopIndexPage,
    },
    {
        path: ':courseId/:cmId/:submissionId',
        component: AddonModWorkshopSubmissionPage,
        canDeactivate: [canLeaveGuard],
    },
    {
        path: ':courseId/:cmId/:submissionId/edit',
        component: AddonModWorkshopEditSubmissionPage,
        canDeactivate: [canLeaveGuard],
    },
    {
        path: ':courseId/:cmId/:submissionId/:assessmentId',
        component: AddonModWorkshopAssessmentPage,
        canDeactivate: [canLeaveGuard],
    },
];

@NgModule({
    imports: [
        RouterModule.forChild(routes),
        CoreSharedModule,
        AddonModWorkshopComponentsModule,
        CoreEditorComponentsModule,
    ],
    declarations: [
        AddonModWorkshopIndexPage,
        AddonModWorkshopSubmissionPage,
        AddonModWorkshopAssessmentPage,
        AddonModWorkshopEditSubmissionPage,
    ],
})
export default class AddonModWorkshopLazyModule {}
