// (C) Copyright 2015 Moodle Pty Ltd.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import { Injectable } from '@angular/core';

import { CoreQuestionBehaviourHandler } from '@features/question/services/behaviour-delegate';
import { CoreQuestionQuestionParsed } from '@features/question/services/question';
import { CoreQuestionHelper } from '@features/question/services/question-helper';
import { makeSingleton } from '@singletons';

/**
 * Handler to support interactive countback question behaviour.
 */
@Injectable({ providedIn: 'root' })
export class AddonQbehaviourInteractiveCountbackHandlerService implements CoreQuestionBehaviourHandler {

    name = 'AddonQbehaviourInteractiveCountback';
    type = 'interactivecountback';

    /**
     * @inheritdoc
     */
    handleQuestion(question: CoreQuestionQuestionParsed): void {
        // Just extract the button, it doesn't need any specific component.
        CoreQuestionHelper.extractQbehaviourButtons(question);
    }

    /**
     * @inheritdoc
     */
    async isEnabled(): Promise<boolean> {
        return true;
    }

}

export const AddonQbehaviourInteractiveCountbackHandler = makeSingleton(AddonQbehaviourInteractiveCountbackHandlerService);
